@@ -23,13 +23,20 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#include <Rmath.h>
+// #include <inttypes.h>
+
+
 #include <stdio.h>
+#include "def.h"
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "Processes.h"
 #include "operator.h"
 #include "rf_interfaces.h"
 #include "variogramAndCo.h"
+#include "extern.h"
 
 #define BR_MESHSIZE (LAST_MAXSTABLE + 1)
 #define BR_VERTNUMBER (LAST_MAXSTABLE + 2)
