@@ -30,15 +30,15 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
- 
+
+#include "def.h"
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "Processes.h"
 #include "families.h"
 #include "Coordinate_systems.h"
-//#include <R_ext/Lapack.h>
-//#include <R_ext/Applic.h>
-//#include <R_ext/Utils.h>     
-//#include <R_ext/BLAS.h> 
 
 
 void kdefault(model *cov, int i, double v) {
@@ -730,7 +730,7 @@ void DD_2(double *x, model *cov, double *v) {
 
 void DD_3(double VARIABLE_IS_NOT_USED *x, model VARIABLE_IS_NOT_USED *cov, double VARIABLE_IS_NOT_USED *v) {
   assert(everyCoord(isSpaceIsotropic, cov));
-  ERR("DD_3 to be programmed\n");
+  ERR0("DD_3 to be programmed\n");
 }
 
 
