@@ -21,13 +21,16 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-//#include <Rmath.h>  
 #include <stdio.h>  
 #include <string.h>
-#include "questions.h"
-#include <Rdefines.h>
 #include <stdint.h>
 
+#include <Basic_utils.h>
+#include <Rdefines.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
+#include "extern.h"
+#include "questions.h"
 #include "Coordinate_systems.h"
 #include "operator.h"
 #include "Processes.h"
@@ -389,7 +392,7 @@ SEXP IGetModelInfo(model *cov, int prlevel, bool both, int spConform,
     switch(prlevel) {
     case 0 : break;
     case 6 : nmodelinfo += 1; break;
-    default : ERR("Possible 'level' values range from 0 to 6.");
+    default : ERR0("Possible 'level' values range from 0 to 6.");
     }
   }
   }
@@ -956,7 +959,7 @@ void pmi(model *cov, char all_subs, int level, int maxlevel,
   //  printI(cov);printD(cov);
    leer(level); PRINTF("%-10s %s\n", "param", C->kappas == 0 ? "none" : ""); 
 
-  for(int i=0; i<C->kappas; i++) {
+  for (int i=0; i<C->kappas; i++) {
     //    printf("[[ %s %s ]]  ", C->kappanames[i],
     //	   cov->ownkappanames != NULL ? cov->ownkappanames[i] : "---");
     
@@ -985,9 +988,12 @@ void pmi(model *cov, char all_subs, int level, int maxlevel,
 	else PRINTF("[%d, %d] ", NROW(i), NCOL(i));
       } 
       switch(C->kappatype[i]) {
-      case REALSXP : for (int j=0; j<endfor; j++) PRINTREAL(P(i)[j]); break;
-      case INTSXP : for (int j=0; j<endfor; j++) PRINTINT(PINT(i)[j]); break;
-      case STRSXP : for (int j=0; j<endfor; j++) PRINTF(" %s", PCHAR(i)[j]); break;
+      case REALSXP : for (int j=0; j<endfor; j++) PRINTREAL(P(i)[j]);
+	break;
+      case INTSXP : for (int j=0; j<endfor; j++) PRINTINT(PINT(i)[j]);
+	break;
+      case STRSXP : for (int j=0; j<endfor; j++) PRINTF(" %s", PCHAR(i)[j]);
+	break;
       case CLOSXP : PRINTF("< arbitrary function >"); break;
       case VECSXP : PRINTF("< some R list >"); break;
       case LANGSXP: PRINTF("< language expression >"); break;
@@ -1329,7 +1335,8 @@ void pmi(model *cov, char all_subs, int level, int maxlevel,
       
 #define SHOWDEFAULT(Z, X, Y) if (pgs->X != NULL) {			\
 	leer(level);  PRINTF("%-10s ",Z);				\
-	for (int d=0; d<dim; d++) PRINTF(Y, pgs->X[d]); PRINTF("\n");}
+	for (int d=0; d<dim; d++) { PRINTF(Y, pgs->X[d]); }		\
+	PRINTF("\n");}
 #define SHOW(Z, X) SHOWDEFAULT(Z, X, "%g ")
 #define SHOWINT(Z, X) SHOWDEFAULT(Z, X, "%d ")
       
@@ -1366,11 +1373,14 @@ void pmi(model *cov, char all_subs, int level, int maxlevel,
 	SHOW("pgs:half", halfstepvector);
 	if (pgs->single != NULL) {
 	  leer(level); { PRINTF("%-10s ","pgs:single"); 
-	    for (int d=0; d<size; d++) PRINTF("%g ", pgs->single[d]);PRINTF("\n"); }
+	    for (int d=0; d<size; d++) PRINTF("%g ", pgs->single[d]);
+	    PRINTF("\n");
+	  }
 	}
 	if (pgs->total != NULL) {
 	  leer(level); { PRINTF("%-10s ","pgs:total"); 
-	    for (int d=0; d<size; d++) PRINTF("%g ", pgs->total[d]); PRINTF("\n"); }
+	    for (int d=0; d<size; d++) PRINTF("%g ", pgs->total[d]);
+	    PRINTF("\n"); }
 	}
       } else { // gauss oder poisson
 	leer(level); P10("pgs:intens", pgs->intensity);
@@ -1513,7 +1523,7 @@ void iexplDollar(model *cov, bool MLEnatsc_only) {
     INVERSE(&GLOBAL.gauss.approx_zero, next, &invscale);
     //invscale = 1.0;
     if (ISNAN(invscale))
-      ERR("inverse function unknown when calculating explicite scale");
+      ERR0("inverse function unknown when calculating explicite scale");
     
     p = PARAM(dollar, DSCALE);
     if (p != NULL) {
@@ -1594,7 +1604,7 @@ SEXP IGetModel(model *cov, int modus, int spConform, bool solveRandom,
    //   if (spConform >= 1) { SET_VECTOR_ELT(Model, k++, mkString(CC->nick));
    // } else {  SET_VECTOR_ELT(Model, k++, mkString(CC->name)); }
 
-  for(i=0; i<C->kappas; i++) {
+  for (i=0; i<C->kappas; i++) {
     if (cov->kappasub[i] != NULL && (!solveRandom || PisNULL(i))) {
       SET_STRING_ELT(nameMvec, k, mkChar(OWNKAPPA(C, i)));
       SET_VECTOR_ELT(Model, k++,
