@@ -21,12 +21,14 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#include <R.h>
-#include <Rdefines.h>
 #include <stdio.h>  
- #include <string.h>
+#include <string.h>
+#include <Basic_utils.h>
+#include <Rdefines.h>
 #include <R_ext/Linpack.h>
-
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
+#include "extern.h"
 #include "questions.h"
 #include "primitive.h"
 #include "Coordinate_systems.h"
