@@ -26,8 +26,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define RFsimu_H 1
 
 // ACHTUNG : REIHENFOLGE WICHTIG
-#include <Basic_utils.h>
-#include "def.h"
 #include "basic.h"
 #include "init.h"
 
@@ -48,8 +46,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // #define MEMCOPY(A,B,C) memory_copy(A, B, C)
 
 
-#include <string.h>
-#include <General_utils.h>
 #include "AutoRandomFields.h"
 #include "auxiliary.h"
 #include "RandomFields.h"
@@ -537,8 +533,18 @@ typedef struct ce_storage {
     // da sonst bei internal_dosimulate die parameter alle RFparameter alle
     // nochmals gesetzt werden muessen
 #ifdef DO_PARALLEL
+#ifdef _OPENMP
+  // later only on SCHLATHERS_MACHINE
+  //  #pragma message "using OMP"
+  //#endif
+#else
+#error parallel although OMP not available
+#endif  
   FFT_storage FFT[MAXMPPVDIM * MAXMPPVDIM];
 #else
+#ifdef _OPENMP
+#warning not using OMP although OMP available
+#endif  
   FFT_storage FFT;
 #endif
   FFT_storage XFFT; // to be deleted
@@ -1634,8 +1640,8 @@ int rPoissonPolygon2(polygon_storage *S, double lambda, bool do_centering);
 	assert((cov)->S##new == NULL);			       	\
     }								\
     (cov)->S##new = (new##_storage *) MALLOC(sizeof(new##_storage));	\
-      Ext_##new##_NULL((cov)->S##new);					\
-    if ((cov)->S##new == NULL) BUG;					\
+     if ((cov)->S##new == NULL) BUG;					\
+     Ext_##new##_NULL((cov)->S##new);					\
   }					
 
 
@@ -1649,8 +1655,8 @@ int rPoissonPolygon2(polygon_storage *S, double lambda, bool do_centering);
   }								\
   if ((cov)->S##new == NULL) {					\
     (cov)->S##new = (new##_storage *) MALLOC(sizeof(new##_storage));	\
-    new##_NULL((cov)->S##new);					\
     if ((cov)->S##new == NULL) BUG;				\
+    new##_NULL((cov)->S##new);					\
   }}   	
 #define NEW_STORAGE(new)	\
   NEW_COV_STORAGE(cov, new)
@@ -1663,8 +1669,8 @@ int rPoissonPolygon2(polygon_storage *S, double lambda, bool do_centering);
   }								\
   if ((cov)->S##new == NULL) {					\
     (cov)->S##new = (new##_storage *) MALLOC(sizeof(new##_storage));	\
-    new##_NULL((cov)->S##new);					\
     if ((cov)->S##new == NULL) BUG;				\
+    new##_NULL((cov)->S##new);					\
   }}								
 #define NEW_STORAGE_WITH_SAVE(new)	\
   NEW_COV_STORAGE_WITH_SAVE(cov, new)
@@ -1673,8 +1679,8 @@ int rPoissonPolygon2(polygon_storage *S, double lambda, bool do_centering);
 #define ONCE_NEW_COV_STORAGE(cov, new)		\
    if ((cov)->S##new == NULL) {					\
    (cov)->S##new = (new##_storage *) MALLOC(sizeof(new##_storage));	\
-   new##_NULL((cov)->S##new);						\
    if ((cov)->S##new == NULL) BUG;					\
+   new##_NULL((cov)->S##new);						\
    }								
 
 #define ONCE_NEW_STORAGE(new)	\
@@ -1688,8 +1694,8 @@ int rPoissonPolygon2(polygon_storage *S, double lambda, bool do_centering);
   }								\
   if (cov->S##new == NULL) {					\
    cov->S##new = (new##_storage *) MALLOC(sizeof(new##_storage));	\
-    new##_NULL(cov->S##new);					\
     if (cov->S##new == NULL) BUG;					\
+    new##_NULL(cov->S##new);					\
   }								\
   assert(cov->S##new->WHAT == NULL);				\
   }
@@ -1712,7 +1718,6 @@ int rPoissonPolygon2(polygon_storage *S, double lambda, bool do_centering);
     Z = cov->Snew->WHAT = (int*) MALLOC(sizeof(int) * (SIZE))
 
 
-#define DISTMAXSTEPS 1000
 #define XSIZE 16
 #define XXSIZE 116
 #define XXXSIZE 1116 // >= DISTAMAXSTEPS + 2 *dim
