@@ -21,9 +21,13 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#include <Rmath.h>
+#include "def.h"
 #include <stdio.h>  
+#include <Basic_utils.h>
 #include <R_ext/Lapack.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
+#include "extern.h"
 #include "questions.h"
 #include "operator.h"
 #include "Processes.h"
