@@ -21,18 +21,19 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#include <Rmath.h>
 #include <stdio.h>  
-//#include <stdlib.h>
+#include "def.h"
+#include <Basic_utils.h>
 #include <R_ext/Lapack.h>
 
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
+#include "extern.h"
 #include "questions.h"
 #include "Coordinate_systems.h"
 #include "Processes.h"
 #include "variogramAndCo.h"
-//#include "userinterfaces.h"
-//#include <R_ext/Linpack.h>
-
+extern const char *direct[directN];
 
 int check_directGauss(model *cov) {
 #define nsel 4
