@@ -32,6 +32,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <stdio.h>  
 #include <string.h>
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "RF.h"
 #include "operator.h"
 #include "startGetNset.h"
@@ -40,6 +43,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "questions.h"
 #include "shape.h"
 #include "primitive.others.h"
+#include "extern.h"
 
 
 KEY_type *PIDKEY[PIDMODULUS];
