@@ -25,6 +25,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <stdio.h>   
 #include <string.h>
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "RF.h"
 #include "startGetNset.h"
 #include "Processes.h"
@@ -32,8 +35,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "rf_interfaces.h"
 #include "primitive.others.h"
 #include "operator.h"
-
-
+extern const char * distr[distrN];
+extern const char *CE[CEN];
 
 
 
