@@ -21,14 +21,17 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#include <Rmath.h>
 #include <stdio.h>  
-//#include <stdlib.h>
+#include "def.h"
+#include <Basic_utils.h>
 #include <R_ext/Lapack.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
+#include "extern.h"
 #include "questions.h"
 #include "Processes.h"
 #include "Coordinate_systems.h"
-
+extern const char *direct[directN];
 
 #define SEQU_BACK (COMMON_GAUSS + 1)
 #define SEQU_INIT (COMMON_GAUSS + 2)
