@@ -32,8 +32,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
+#include "def.h"
+#include <Basic_utils.h>
 #include <R_ext/Linpack.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 
+#include "extern.h"
 #include "questions.h"
 #include "shape.h"
 #include "operator.h"
@@ -179,7 +184,7 @@ void covariate(double *x, model *cov, double *v){
     // should happen only in a matrix context!
     nr = (int) x[dim];
     if (nr * vdim >= LNROW(COVARIATE_C) * LNCOL(COVARIATE_C))
-      ERR("illegal access -- 'raw' should be FALSE");
+      ERR0("illegal access -- 'raw' should be FALSE");
   } else { 
     // interpolate: here nearest neighbour/voronoi
     nr = get_index(x, cov);
@@ -451,7 +456,7 @@ void fix(double *x, double *y, model *cov, double *v){
     nry = y == NULL ? x[dim+1] : (int) y[dim];
     if (nrx * vdim >= LNROW(FIXCOV_M) ||
 	nry * vdim >= LNCOL(FIXCOV_M))
-      ERR("illegal access -- 'raw' should be FALSE");
+      ERR0("illegal access -- 'raw' should be FALSE");
   } else {    
     nrx = get_index(x, cov);
     nry = get_index(y, cov);
@@ -1095,7 +1100,7 @@ void EtAxxA(double *x, model *cov, double *v) {
     *E = P(EAXXA_E),
     *A = P(EAXXA_A),
     phi = P0(ETAXXA_ALPHA),
-    c =  cos(phi * x[time]),
+    c =  COS(phi * x[time]),
     s = SIN(phi * x[time]); 
      
   R[0] = R[4] = c;
@@ -1197,7 +1202,7 @@ void rotat(double *x, model *cov, double *v) {
     phi = P0(ROTAT_PHI),
     absx = SQRT(x[0] * x[0] + x[1] * x[1]);
   *v = (absx == 0.0) ? 0.0
-    : speed * (cos(phi * x[time]) * x[0] + SIN(phi * x[time]) * x[1]) / absx;
+    : speed * (COS(phi * x[time]) * x[0] + SIN(phi * x[time]) * x[1]) / absx;
 }
 
 void minmaxEigenrotat(model VARIABLE_IS_NOT_USED *cov, double *mm) {
@@ -1240,7 +1245,7 @@ void Rotat(double *x, model *cov, double *v) {
     time = dim - 1;
   double
     phi = P0(ROTAT_PHI),
-      c =  cos(phi * x[time]),
+      c =  COS(phi * x[time]),
       s = SIN(phi * x[time]),
       R[9]; assert(dim ==3);
    
